package anywheresoftware.b4a.object;

import com.andexert.library.RippleView;

import android.view.View;
import android.view.ViewGroup;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.ActivityObject;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.BALayout.LayoutParams;
import anywheresoftware.b4a.objects.ConcreteViewWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
@ActivityObject
@ShortName("RippleView")
@Version(1.3f)
public class RippleViewWrapper extends ViewWrapper<RippleView>
{
	/**
	 * Adds a ripple effect to the view.
	 * Color - Ripple color.
	 * DurationMs - Animation duration in milliseconds.
	 * Centered - Whether to start the effect from the touch position or from the center.
	 */
	public void Initialize(BA ba, ConcreteViewWrapper View, int Color, int DurationMs, boolean Centered)
	{
		if (IsInitialized())
			throw new RuntimeException("Already initialized");
		setObject(new RippleView(ba.context, Color, DurationMs, Centered));
		setB4AView(View);
	}

	private void setB4AView(ConcreteViewWrapper b4aView)
	{
		getObject().setChildView(b4aView);
		View view = (android.view.View) b4aView.getObject();
		if (view.getParent() == null)
		{
			ViewGroup.LayoutParams lp = new ViewGroup.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.FILL_PARENT);
			getObject().addView(view, 0, lp);
		}
		else {
			ViewGroup vg = (ViewGroup) view.getParent();
			vg.removeView(view);
			LayoutParams lp = (LayoutParams) view.getLayoutParams();
			getObject().addView(view, 0, new ViewGroup.LayoutParams(lp.width, lp.height));
			vg.addView(getObject(), lp);
			b4aView.setWidth(LayoutParams.FILL_PARENT);
			b4aView.setHeight(LayoutParams.FILL_PARENT);
		}
	}

	/**
	 * Sets the ripple animation attributes.
	 * @param Simple - Whether the ripple is simple or double. 
	 * @param Color - The ripple color.
	 * @param DurationMs - The duration of the animation in milliseconds.
	 * @param Centered - Whether to start the effect from the touch position or from the center.
	 * @param Padding - The padding between the effect and the border of the view. Can be negative to enlarge the ripple. 
	 */
	public void Ripple(boolean Simple, int Color, int DurationMs, boolean Centered, int Padding)
	{
		getObject().rippleType = Simple ? 0 : 1;
		getObject().rippleColor = Color;
		getObject().DURATION = DurationMs;
		getObject().isCentered = Centered;
		getObject().ripplePadding = Padding;
	}

	/**
	 * Sets the zoom attributes. The zoom animation is disabled if DurationMs &lt;= 0.
	 */
	public void Zoom(int DurationMs, float Scale)
	{
		getObject().zoomDuration = DurationMs;
		getObject().zoomScale = Scale;
		getObject().hasToZoom = (DurationMs > 0);
	}

	/**
	 * Gets the view embedded in the ripple view.
	 */
	public ConcreteViewWrapper getView()
	{
		return (ConcreteViewWrapper) getObject().getChildView();
	}
}
